@@ -76,7 +76,7 @@ from ruamel.yaml import YAML
 
 
 class info():
-    version = '1.1'
+    version = '1.2'
     description = 'YAML file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -134,6 +134,11 @@ def parse(data, raw=False, quiet=False):
 
     if jc.utils.has_data(data):
 
+        # monkey patch to disable plugins since we don't use them and in
+        # ruamel.yaml versions prior to 0.17.0 the use of __file__ in the
+        # plugin code is incompatible with the pyoxidizer packager
+        YAML.official_plug_ins = lambda a: []
+
         yaml = YAML(typ='safe')
 
         for document in yaml.load_all(data):
